@@ -1,4 +1,6 @@
-#' Display Extended Brand Colour Palette
+#' @title
+#' Extended Brand Colour Palette
+#' @description
 #' Displays extended brand colour palette for charting
 #' @return a Base R plot object
 #' @importFrom scales show_col
@@ -25,6 +27,18 @@ show_extended_palette <- function() {
     )
   )
 
+  print(c(
+    "#9880BB",
+    "#0061BA",
+    "#3BBCD9",
+    "#223873",
+    "#71B72B",
+    "#D585BA",
+    "#007761",
+    "#4D8076",
+    "#00C9A7",
+    "#4A4453",
+    "#C27767",
+    "#D5CABD"
+  ))
 }
-
-
